@@ -1,5 +1,9 @@
+"""Manages command line processes.
+"""
+
+
 import argparse
-import pgnhelper
+import pgnhelper.app
 
 
 def main():
@@ -68,7 +72,7 @@ def main():
 
     g = None
     if args.command == 'sort':
-        g = pgnhelper.PgnHelper(
+        g = pgnhelper.app.PgnHelper(
             args.command,
             inpgnfn=args.inpgnfn,
             outpgnfn=args.outpgnfn,
@@ -77,14 +81,14 @@ def main():
             encoding=args.encoding
         )
     elif args.command == 'addeco':
-        g = pgnhelper.PgnHelper(
+        g = pgnhelper.app.PgnHelper(
             args.command,
             inpgnfn=args.inpgnfn,
             outpgnfn=args.outpgnfn,
             inecopgnfn=args.inecopgnfn            
         )
     elif args.command == 'roundrobin':
-        g = pgnhelper.PgnHelper(
+        g = pgnhelper.app.PgnHelper(
             args.command,
             inpgnfn=args.inpgnfn,
             output=args.output,
